function series = initvalf(M, options) 
% function initvalf(M)
%
% handles options for histvalf() and initvalf()
%
% INPUTS
%    caller:           string, name of calling function
%    M:                model structure
%    options:          options specific to initivalf
%
% OUTPUTS
%    series:           dseries containing selected data from a file or a dseries
%

% Copyright (C) 2003-2020 Dynare Team
%
% This file is part of Dynare.
%
% Dynare is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% Dynare is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.

series = histvalf_initvalf('INITVALF', M, options);